Struct gpgme::ops::EncryptFlags
[−]
pub struct EncryptFlags {
// some fields omitted
}Methods
impl EncryptFlags
fn empty() -> EncryptFlags
Returns an empty set of flags.
fn all() -> EncryptFlags
Returns the set containing all flags.
fn bits(&self) -> gpgme_encrypt_flags_t
Returns the raw value of the flags currently stored.
fn from_bits(bits: gpgme_encrypt_flags_t) -> Option<EncryptFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: gpgme_encrypt_flags_t) -> EncryptFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: EncryptFlags) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: EncryptFlags) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: EncryptFlags)
Inserts the specified flags in-place.
fn remove(&mut self, other: EncryptFlags)
Removes the specified flags in-place.
fn toggle(&mut self, other: EncryptFlags)
Toggles the specified flags in-place.