Struct gpgme::ops::KeyListMode
[−]
pub struct KeyListMode {
// some fields omitted
}Methods
impl KeyListMode
fn empty() -> KeyListMode
Returns an empty set of flags.
fn all() -> KeyListMode
Returns the set containing all flags.
fn bits(&self) -> gpgme_keylist_mode_t
Returns the raw value of the flags currently stored.
fn from_bits(bits: gpgme_keylist_mode_t) -> Option<KeyListMode>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: gpgme_keylist_mode_t) -> KeyListMode
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: KeyListMode) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: KeyListMode) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: KeyListMode)
Inserts the specified flags in-place.
fn remove(&mut self, other: KeyListMode)
Removes the specified flags in-place.
fn toggle(&mut self, other: KeyListMode)
Toggles the specified flags in-place.